@@ -6,7 +6,6 @@
 
 extern crate rutabaga_gfx;
 
-use std::cell::RefCell;
 use std::convert::TryInto;
 use std::ffi::CStr;
 use std::ffi::CString;
@@ -23,6 +22,8 @@ use std::ptr::copy_nonoverlapping;
 use std::ptr::null_mut;
 use std::slice::from_raw_parts;
 use std::slice::from_raw_parts_mut;
+use std::sync::Mutex;
+use std::sync::OnceLock;
 
 #[cfg(unix)]
 use libc::iovec;
@@ -32,7 +33,7 @@ use rutabaga_gfx::ResourceCreate3D;
 use rutabaga_gfx::ResourceCreateBlob;
 use rutabaga_gfx::Rutabaga;
 use rutabaga_gfx::RutabagaBuilder;
-use rutabaga_gfx::RutabagaChannel;
+use rutabaga_gfx::RutabagaComponentType;
 use rutabaga_gfx::RutabagaDebug;
 use rutabaga_gfx::RutabagaDebugHandler;
 use rutabaga_gfx::RutabagaDescriptor;
@@ -43,6 +44,7 @@ use rutabaga_gfx::RutabagaHandle;
 use rutabaga_gfx::RutabagaImportData;
 use rutabaga_gfx::RutabagaIntoRawDescriptor;
 use rutabaga_gfx::RutabagaIovec;
+use rutabaga_gfx::RutabagaPath;
 use rutabaga_gfx::RutabagaRawDescriptor;
 use rutabaga_gfx::RutabagaResult;
 use rutabaga_gfx::RutabagaWsi;
@@ -59,23 +61,20 @@ pub struct iovec {
 const NO_ERROR: i32 = 0;
 const RUTABAGA_WSI_SURFACELESS: u64 = 1;
 
-thread_local! {
-    static S_DEBUG_HANDLER: RefCell<Option<RutabagaDebugHandler>> = const { RefCell::new(None) };
-}
+static S_DEBUG_HANDLER: OnceLock<Mutex<RutabagaDebugHandler>> = OnceLock::new();
 
 fn log_error(debug_string: String) {
-    S_DEBUG_HANDLER.with(|handler_cell| {
-        if let Some(handler) = &*handler_cell.borrow() {
-            let cstring = CString::new(debug_string.as_str()).expect("CString creation failed");
+    if let Some(handler_mutex) = S_DEBUG_HANDLER.get() {
+        let cstring = CString::new(debug_string.as_str()).expect("CString creation failed");
 
-            let debug = RutabagaDebug {
-                debug_type: RUTABAGA_DEBUG_ERROR,
-                message: cstring.as_ptr(),
-            };
+        let debug = RutabagaDebug {
+            debug_type: RUTABAGA_DEBUG_ERROR,
+            message: cstring.as_ptr(),
+        };
 
-            handler.call(debug);
-        }
-    });
+        let handler = handler_mutex.lock().unwrap();
+        handler.call(debug);
+    }
 }
 
 fn return_result<T>(result: RutabagaResult<T>) -> i32 {
@@ -225,16 +224,14 @@ pub unsafe extern "C" fn rutabaga_init(builder: &rutabaga_builder, ptr: &mut *mu
 
         if let Some(func) = builder.debug_cb {
             let debug_handler = create_ffi_debug_handler(builder.user_data, func);
-            S_DEBUG_HANDLER.with(|handler_cell| {
-                *handler_cell.borrow_mut() = Some(debug_handler.clone());
-            });
+            let _ = S_DEBUG_HANDLER.set(Mutex::new(debug_handler.clone()));
             debug_handler_opt = Some(debug_handler);
         }
 
-        let mut rutabaga_channels_opt = None;
-        if let Some(channels) = builder.channels {
-            let mut rutabaga_channels: Vec<RutabagaChannel> = Vec::new();
-            let channels_slice = from_raw_parts(channels.channels, channels.num_channels);
+        let mut rutabaga_paths_opt = None;
+        if let Some(paths) = builder.channels {
+            let mut rutabaga_paths: Vec<RutabagaPath> = Vec::new();
+            let channels_slice = from_raw_parts(paths.channels, paths.num_channels);
 
             for channel in channels_slice {
                 let c_str_slice = CStr::from_ptr(channel.channel_name);
@@ -243,13 +240,13 @@ pub unsafe extern "C" fn rutabaga_init(builder: &rutabaga_builder, ptr: &mut *mu
                 let string = str_slice.to_owned();
                 let path = PathBuf::from(&string);
 
-                rutabaga_channels.push(RutabagaChannel {
-                    base_channel: path,
-                    channel_type: channel.channel_type,
+                rutabaga_paths.push(RutabagaPath {
+                    path,
+                    path_type: channel.channel_type,
                 });
             }
 
-            rutabaga_channels_opt = Some(rutabaga_channels);
+            rutabaga_paths_opt = Some(rutabaga_paths);
         }
 
         let mut renderer_features_opt = None;
@@ -267,12 +264,18 @@ pub unsafe extern "C" fn rutabaga_init(builder: &rutabaga_builder, ptr: &mut *mu
             _ => return -EINVAL,
         };
 
+        let mut component = RutabagaComponentType::NoneSelected;
+        if builder.capset_mask == 0 {
+            component = RutabagaComponentType::Rutabaga2D;
+        }
+
         let result = RutabagaBuilder::new(builder.capset_mask, fence_handler)
+            .set_default_component(component)
             .set_use_external_blob(false)
             .set_use_egl(true)
             .set_wsi(rutabaga_wsi)
             .set_debug_handler(debug_handler_opt)
-            .set_rutabaga_channels(rutabaga_channels_opt)
+            .set_rutabaga_paths(rutabaga_paths_opt)
             .set_renderer_features(renderer_features_opt)
             .build();
 
