@@ -10,6 +10,7 @@ use crate::rutabaga_utils::RutabagaDebugHandler;
 use crate::rutabaga_utils::RutabagaError;
 use crate::rutabaga_utils::RutabagaFenceHandler;
 use crate::rutabaga_utils::RutabagaResult;
+use crate::RutabagaPaths;
 
 #[repr(C)]
 #[derive(Debug, Copy, Clone)]
@@ -33,5 +34,7 @@ pub struct RutabagaCookie {
     #[allow(dead_code)]
     pub render_server_fd: Option<OwnedDescriptor>,
     pub fence_handler: Option<RutabagaFenceHandler>,
+    #[allow(dead_code)]
     pub debug_handler: Option<RutabagaDebugHandler>,
+    pub rutabaga_paths: Option<RutabagaPaths>,
 }
